==> react-bs-datatable-3.0.2.tgz: package/lib/esm/components/TableBody.js <==
import React from 'react';
import { Form } from 'react-bootstrap';
import { makeClasses } from '../helpers/object';
import { useDatatableWrapper } from './DatatableWrapper';
import { getNextCheckboxState } from '../helpers/checkbox';
/**
 * Renders the table body, which is a `tbody` tag along with the rest of the elements,
 * such as `tr` and `td` tags.
 */
export function TableBody({ labels, classes, onRowClick: onRowClickProp, controlledProps }) {
    const { data, headers, onCheckboxChange: onCheckboxChangeContext, checkboxState: checkboxStateContext, filteredDataLength: filteredDataLengthContext, checkboxRefs } = useDatatableWrapper();
    const body = [];
    const dataLength = data.length;
    const headersLength = headers.length;
    function onRowClick(rowIdx) {
        if (typeof onRowClickProp === 'function') {
            onRowClickProp(data[rowIdx]);
        }
    }
    const onCheckboxChange = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.onCheckboxChange) || onCheckboxChangeContext;
    const checkboxState = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.checkboxState) || checkboxStateContext;
    const filteredDataLength = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.filteredDataLength) || filteredDataLengthContext;
    if (dataLength > 0) {
        for (let rowIdx = 0; rowIdx < dataLength; rowIdx++) {
            const row = [];
            for (let colIdx = 0; colIdx < headersLength; colIdx++) {
                const { cell, cellProps = {}, prop: rawProp, checkbox, alignment } = headers[colIdx];
                const prop = rawProp.toString();
                let value = '';
                if (checkbox) {
                    // Render checkbox.
                    const idValue = data[rowIdx][checkbox.idProp];
                    const isSelected = checkboxState[prop].selected.has(idValue);
                    // Source for using visually hidden: https://www.w3.org/WAI/tutorials/forms/labels/#hiding-the-label-element.
                    value = (React.createElement(Form.Group, { controlId: `table-selection-${data[rowIdx][checkbox.idProp]}` },
                        React.createElement(Form.Label, { className: "visually-hidden" }, isSelected
                            ? `Remove ${idValue} from selection`
                            : `Add ${idValue} to selection`),
                        React.createElement(Form.Check, { type: "checkbox", name: "table-selection", value: data[rowIdx][checkbox.idProp], className: checkbox.className, checked: checkboxState[prop].selected.has(idValue), onChange: () => {
                                onCheckboxChange({
                                    prop,
                                    idProp: checkbox.idProp,
                                    nextCheckboxState: getNextCheckboxState({
                                        checkboxState,
                                        data: data[rowIdx],
                                        idProp: checkbox.idProp,
                                        filteredDataLength,
                                        prop,
                                        type: isSelected ? 'remove' : 'add'
                                    }),
                                    checkboxRefs
                                });
                            } })));
                }
                else {
                    // Render normally.
                    if (cell === undefined) {
                        value = data[rowIdx][prop];
                    }
                    else {
                        value = cell(data[rowIdx]);
                    }
                }
                row.push(React.createElement("td", { key: `col-${rowIdx}${colIdx}`, className: makeClasses('tbody-td', classes === null || classes === void 0 ? void 0 : classes.td, 
                    // Alignment.
                    {
                        'text-start': (alignment === null || alignment === void 0 ? void 0 : alignment.horizontal) === 'left',
                        'text-center': (alignment === null || alignment === void 0 ? void 0 : alignment.horizontal) === 'center',
                        'text-end': (alignment === null || alignment === void 0 ? void 0 : alignment.horizontal) === 'right'
                    }, typeof cellProps.className === 'function'
                        ? cellProps.className(data[rowIdx])
                        : cellProps.className), style: typeof cellProps.style === 'function'
                        ? cellProps.style(data[rowIdx])
                        : cellProps.style }, value));
            }
            body.push(React.createElement("tr", { key: rowIdx, className: makeClasses('tbody-tr', classes === null || classes === void 0 ? void 0 : classes.tr), onClick: () => onRowClick(rowIdx) }, row));
        }
    }
    else {
        body.push(React.createElement("tr", { key: `row-zero-length`, className: "tbody-tr" },
            React.createElement("td", { className: "tbody-td", colSpan: headers.length }, (labels === null || labels === void 0 ? void 0 : labels.noResults) || 'No results to be shown.')));
    }
    return React.createElement("tbody", { className: makeClasses('tbody', classes === null || classes === void 0 ? void 0 : classes.tbody) }, body);
}

==> react-bs-datatable-3.3.0.tgz: package/lib/esm/components/TableBody.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import { Form } from 'react-bootstrap';
import { makeClasses } from '../helpers/object';
import { useDatatableWrapper } from './DatatableWrapper';
import { getNextCheckboxState } from '../helpers/checkbox';
/**
 * Renders the table body, which is a `tbody` tag along with the rest of the elements,
 * such as `tr` and `td` tags.
 */
export function TableBody({ labels, classes, rowProps, onRowClick: onRowClickProp, controlledProps }) {
    const { data, headers, onCheckboxChange: onCheckboxChangeContext, checkboxState: checkboxStateContext, filteredDataLength: filteredDataLengthContext, checkboxRefs } = useDatatableWrapper();
    const body = [];
    const dataLength = data.length;
    const headersLength = headers.length;
    function onRowClick(rowIdx) {
        if (typeof onRowClickProp === 'function') {
            onRowClickProp(data[rowIdx]);
        }
    }
    const onCheckboxChange = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.onCheckboxChange) || onCheckboxChangeContext;
    const checkboxState = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.checkboxState) || checkboxStateContext;
    const filteredDataLength = (controlledProps === null || controlledProps === void 0 ? void 0 : controlledProps.filteredDataLength) || filteredDataLengthContext;
    if (dataLength > 0) {
        for (let rowIdx = 0; rowIdx < dataLength; rowIdx++) {
            const row = [];
            for (let colIdx = 0; colIdx < headersLength; colIdx++) {
                const { cell, cellProps = {}, prop: rawProp, checkbox, alignment } = headers[colIdx];
                const prop = rawProp.toString();
                let value = '';
                if (checkbox) {
                    // Render checkbox.
                    const idValue = data[rowIdx][checkbox.idProp];
                    const isSelected = checkboxState[prop].selected.has(idValue);
                    // Source for using visually hidden: https://www.w3.org/WAI/tutorials/forms/labels/#hiding-the-label-element.
                    value = (React.createElement(Form.Group, { controlId: `table-selection-${data[rowIdx][checkbox.idProp]}` },
                        React.createElement(Form.Label, { className: "visually-hidden" }, isSelected
                            ? `Remove ${idValue} from selection`
                            : `Add ${idValue} to selection`),
                        React.createElement(Form.Check, { type: "checkbox", name: "table-selection", value: data[rowIdx][checkbox.idProp], className: checkbox.className, checked: checkboxState[prop].selected.has(idValue), onChange: () => {
                                onCheckboxChange({
                                    prop,
                                    idProp: checkbox.idProp,
                                    nextCheckboxState: getNextCheckboxState({
                                        checkboxState,
                                        data: data[rowIdx],
                                        idProp: checkbox.idProp,
                                        filteredDataLength,
                                        prop,
                                        type: isSelected ? 'remove' : 'add'
                                    }),
                                    checkboxRefs
                                });
                            } })));
                }
                else {
                    // Render normally.
                    if (cell === undefined) {
                        value = data[rowIdx][prop];
                    }
                    else {
                        value = cell(data[rowIdx]);
                    }
                }
                row.push(React.createElement("td", { key: `col-${rowIdx}${colIdx}`, className: makeClasses('tbody-td', classes === null || classes === void 0 ? void 0 : classes.td, 
                    // Alignment.
                    {
                        'text-start': (alignment === null || alignment === void 0 ? void 0 : alignment.horizontal) === 'left',
                        'text-center': (alignment === null || alignment === void 0 ? void 0 : alignment.horizontal) === 'center',
                        'text-end': (alignment === null || alignment === void 0 ? void 0 : alignment.horizontal) === 'right'
                    }, typeof cellProps.className === 'function'
                        ? cellProps.className(data[rowIdx])
                        : cellProps.className), style: typeof cellProps.style === 'function'
                        ? cellProps.style(data[rowIdx])
                        : cellProps.style }, value));
            }
            const _a = typeof rowProps === 'function'
                ? rowProps(data[rowIdx])
                : rowProps || {}, { className: rowCustomClassName } = _a, restProps = __rest(_a, ["className"]);
            body.push(React.createElement("tr", Object.assign({ key: rowIdx }, restProps, { className: makeClasses('tbody-tr', classes === null || classes === void 0 ? void 0 : classes.tr, rowCustomClassName), onClick: () => onRowClick(rowIdx) }), row));
        }
    }
    else {
        body.push(React.createElement("tr", { key: `row-zero-length`, className: "tbody-tr" },
            React.createElement("td", { className: "tbody-td", colSpan: headers.length }, (labels === null || labels === void 0 ? void 0 : labels.noResults) || 'No results to be shown.')));
    }
    return React.createElement("tbody", { className: makeClasses('tbody', classes === null || classes === void 0 ? void 0 : classes.tbody) }, body);
}
